:github_url: https://github.com/stephane-caron/pink/tree/master/doc/src/extras.rst

******
Extras
******

Robot models
============

.. automodule:: pink.models
    :members:

JVRC humanoid
-------------

.. automodule:: pink.models.jvrc
    :members:
